# Welcome to the pycompwa website!

<!-- cspell:ignore genindex modindex -->

:::{warning}

`pycompwa` is no longer maintained. Use the
[ComPWA](https://compwa-org.rtfd.io) packages [QRules](https://qrules.rtfd.io),
[AmpForm](https://ampform.rtfd.io), and
[TensorWaves](https://tensorwaves.rtfd.io) instead!

:::

The {mod}`pycompwa` package is a collection of python modules that interface
and extend the "Common Partial-Wave-Analysis Framework"
([ComPWA](https://github.com/ComPWA/ComPWA)). These pages provide information
about the installation, how-tos to get things running, information on the
design, as well as documentation of the ongoing development.

```{toctree}
:maxdepth: 3

install
usage
develop
documents
API <api/pycompwa>
```

- {ref}`Python API <modindex>`
- {ref}`General Index <genindex>`
- {ref}`Search <search>`

```{toctree}
---
caption: Related projects
hidden:
---
QRules <https://qrules.readthedocs.io>
AmpForm <https://ampform.readthedocs.io>
TensorWaves <https://tensorwaves.readthedocs.io>
PWA Pages <https://pwa.readthedocs.io>
```

```{toctree}
---
caption: ComPWA Organization
hidden:
---
Website <https://compwa-org.readthedocs.io>
GitHub Repositories <https://github.com/ComPWA>
About <https://compwa-org.readthedocs.io/en/stable/about.html>
```
